@@ -57,7 +57,6 @@ __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Thermal_Printer.git"
 
 
-# pylint: disable=bad-whitespace
 # Internally used constants.
 _UPDOWN_MASK = const(1 << 2)
 _BOLD_MASK = const(1 << 3)
@@ -74,7 +73,6 @@ SIZE_MEDIUM = const(1)
 SIZE_LARGE = const(2)
 UNDERLINE_THIN = const(0)
 UNDERLINE_THICK = const(1)
-# pylint: enable=bad-whitespace
 
 
 # Disable too many instance members warning.  This is not something pylint can
@@ -104,9 +102,8 @@ UNDERLINE_THICK = const(1)
 # else it will be very easy to break or introduce subtle incompatibilities with
 # older firmware printers.
 class ThermalPrinter:
-    """Thermal printer for printers with firmware version 2.68 or higher."""
+    """Thermal printer for printers with firmware version from 2.68 and below 2.168"""
 
-    # pylint: disable=bad-whitespace
     # Barcode types.  These vary based on the firmware version so are made
     # as class-level variables that users can reference (i.e.
     # ThermalPrinter.UPC_A, etc) and write code that is independent of the
@@ -120,7 +117,6 @@ class ThermalPrinter:
     CODABAR = 71
     CODE93 = 72
     CODE128 = 73
-    # pylint: enable=bad-whitespace
 
     class _PrintModeBit:
         # Internal descriptor class to simplify printer mode change properties.
@@ -184,6 +180,7 @@ class ThermalPrinter:
         self._char_height = 24
         self._line_spacing = 6
         self._barcode_height = 50
+        self.up_down_mode = True
         # pylint: disable=line-too-long
         # Byte delay calculated based on assumption of 19200 baud.
         # From Arduino library code, see formula here:
@@ -391,6 +388,9 @@ class ThermalPrinter:
         self.underline = None
         self.inverse = False
         self.upside_down = False
+        # this should work in 2.68 according to user manual v 4.0
+        # but it does't work with 2.168 hence i implemented the below
+        self.up_down_mode = True
         self.double_height = False
         self.double_width = False
         self.strike = False
@@ -491,7 +491,19 @@ class ThermalPrinter:
     )
     # pylint: enable=line-too-long
 
-    upside_down = _PrintModeBit(_UPDOWN_MASK)
+    def _set_up_down_mode(self, up_down_mode):
+        if up_down_mode:
+            self.send_command("\x1B{\x01")
+
+        else:
+            self.send_command("\x1B{\x00")
+
+    up_down_mode = property(
+        None, _set_up_down_mode, None, "Turns on/off upside-down printing mode"
+    )
+    # The above Should work in 2.68 so its here and not in 2.168 module
+
+    upside_down = _PrintModeBit(_UPDOWN_MASK)  # Don't work in 2.168 hence the above
 
     double_height = _PrintModeBit(_DOUBLE_HEIGHT_MASK)
 
@@ -526,8 +538,7 @@ class ThermalPrinter:
         self.send_command("\x1B=\x00")  # ESC + '=' + 0
 
     def online(self):
-        """Put the printer into an online state after previously put offline.
-        """
+        """Put the printer into an online state after previously put offline."""
         self.send_command("\x1B=\x01")  # ESC + '=' + 1
 
     def has_paper(self):
